@@ -23,3 +23,5 @@ from .work_order_service import *
 from .work_order_status import *
 from .config import *
 from .power_vend import *
+from .bedroom import *
+from .work_order_bedroom import *
