@@ -3,7 +3,7 @@ from .base import BaseModelAbstract
 
 
 class WorkOrderService(BaseModelAbstract, models.Model):
-    name = models.TextField(blank=True, null=True)
+    name = models.TextField(blank=True, null=True, unique=True)
     status = models.CharField(max_length=30, default='active', blank=True, 
                               null=True)
     configure_bedroom = models.BooleanField(default=False)
@@ -25,7 +25,7 @@ class WorkOrderServiceCategory(BaseModelAbstract, models.Model):
     service = models.ForeignKey(
         WorkOrderService, models.SET_NULL, db_column='service',
         blank=True, null=True)
-    name = models.CharField(max_length=255, blank=False, null=False)
+    name = models.CharField(max_length=255, blank=False, null=False, unique=True)
     chargeType = models.CharField(db_column='chargeType', blank=False,
                                   choices=CHARGE_TYPES, default="fixed",
                                   null=False, max_length=15)
